<?php
/**
 * ClickToAddress Integration
 *
 * @package  ClickToAddress Integration
 * @category Integration
 * @author   Crafty Clicks
 */

if ( ! class_exists( 'WC_ClickToAddress_Autocomplete_Integration' ) ) :

class WC_ClickToAddress_Autocomplete_Integration extends WC_Integration {

	/**
	 * Init and hook in the integration.
	 */
	public function __construct() {
		global $woocommerce;

		$this->id				 = 'clicktoaddress_autocomplete';
		$this->method_title	   = __( 'ClickToAddress Auto-Complete', 'woocommerce-clicktoaddress-autocomplete' );
		$this->method_description = __( 'Adds CraftyClicks\' Global Address Finder to WooCommerce checkout pages.', 'woocommerce-clicktoaddress-autocomplete' );

		// Load the settings.
		$this->init_form_fields();
		$this->init_settings();

		// Define user set variables.
		$this->config = (object) array(
			'access_token' => $this->get_option( 'access_token' ),
			'layout' => (int) $this->get_option( 'layout' ),
			'hide_fields' => (int) $this->get_option( 'hide_fields' )
		);

		// Actions.
		add_action( 'woocommerce_update_options_integration_' .  $this->id, array( $this, 'process_admin_options' ) );
		add_action( 'woocommerce_checkout_billing', array( $this, 'addJs' ) );
		add_action( 'woocommerce_before_edit_account_address_form', array( $this, 'addJs' ) );
		// Filters.
		add_filter( 'woocommerce_settings_api_sanitized_fields_' . $this->id, array( $this, 'sanitize_settings' ) );
	}

	public function addJs(){
		if($this->config->access_token != ''){
			printf("<script type='text/javascript'>var cc_c2a_config = %s;</script>",json_encode($this->config));
			wp_enqueue_script('clicktoaddress-autocomplete-js-core','https://cc-cdn.com/generic/scripts/v1/cc_c2a.min.js');
			wp_enqueue_script('clicktoaddress-autocomplete-js-checkout',plugins_url( '../js/checkout.js', __FILE__ ));
		}
	}


	/**
	 * Initialize integration settings form fields.
	 *
	 * @return void
	 */
	public function init_form_fields() {
		$this->form_fields = array(
			'access_token' => array(
				'title'			 => __( 'Access Token', 'woocommerce-clicktoaddress-autocomplete' ),
				'type'			  => 'text',
				'description'	   => __( 'Enter with your API Key. You can find this in "User Profile" drop-down (top right corner) > API Keys.', 'woocommerce-clicktoaddress-autocomplete' ),
				'desc_tip'		  => true,
				'default'		   => 'xxxxx-xxxxx-xxxxx-xxxxx'
			),
			'layout' => array(
				'title'			 => __( 'Search Layout', 'woocommerce-clicktoaddress-autocomplete' ),
				'type'			  => 'select',
				'description'	   => __( 'Choose a layout type', 'woocommerce-clicktoaddress-autocomplete' ),
				'desc_tip'		  => true,
				'default'		   => 1,
				'options'     => array(
					1 => __('Below', 'woocommerce' ),
					2 => __('Surround', 'woocommerce' )
				)
			),
			'hide_fields' => array(
				'title'			 => __( 'Hide Address Fields', 'woocommerce-clicktoaddress-autocomplete' ),
				'type'			  => 'select',
				'description'	   => __( 'Hide the address fields until a search result is selected', 'woocommerce-clicktoaddress-autocomplete' ),
				'desc_tip'		  => true,
				'default'		   => 1,
				'options'     => array(
					0 => __('No', 'woocommerce' ),
					1 => __('Yes', 'woocommerce' )
				)
			)
		);
	}


	/**
	 * Santize our settings
	 * @see process_admin_options()
	 */
	public function sanitize_settings( $settings ) {
		if ( isset( $settings ) &&
			 isset( $settings['api_key'] ) ) {
			$settings['api_key'] = strtoupper( $settings['api_key'] );
		}
		return $settings;
	}

}

endif;
